<?php
/**
 * hasarahouse functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * @link https://codex.wordpress.org/Plugin_API
 *
 * @package EngoTheme
 * @subpackage hasarahouse
 * @since hasarahouse 1.0
 */
define( 'HASARAHOUSE_THEME_VERSION', '1.0' );
/**
 * Set up the content width value based on the theme's design.
 *
 * @see hasarahouse_fnc_content_width()
 *
 * @since hasarahouse 1.0
 */
if ( ! isset( $content_width ) ) {
	$content_width = 474;
}
 
if ( ! function_exists( 'hasarahouse_fnc_setup' ) ) :
/**
 * mode setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 *
 * @since hasarahouse 1.0
 */
function hasarahouse_fnc_setup() {

	/*
	 * Make mode available for translation.
	 *
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on mode, use a find and
	 * replace to change 'hasarahouse' to the name of your theme in all
	 * template files.
	 */
	load_theme_textdomain( 'hasarahouse', get_template_directory() . '/languages' );

	// This theme styles the visual editor to resemble the theme style.
// 	add_editor_style( array( 'css/editor-style.css', hasarahouse_fnc_font_url(), 'genericons/genericons.css' ) );
	// Add RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );
	add_editor_style();
	// Enable support for Post Thumbnails, and declare two sizes.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 672, 372, true );
    add_image_size('property-large-image', 1110, 650, true);

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary'   => esc_html__( 'Top primary menu', 'hasarahouse' ),
		'secondary' => esc_html__( 'Secondary menu in left sidebar', 'hasarahouse' ),
		'topmenu'	=> esc_html__( 'Topbar Menu in Topbar sidebar', 'hasarahouse' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'audio', 'quote', 'link', 'gallery',
	) );

	// This theme allows users to set a custom background.
	add_theme_support( 'custom-background', apply_filters( 'hasarahouse_fnc_custom_background_args', array(
		'default-color' => 'f5f5f5',
	) ) );

	
	// add support for display browser title
	add_theme_support( 'title-tag' );
	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );
	
	hasarahouse_fnc_get_load_plugins();

}
endif; 
// hasarahouse_fnc_setup
add_action( 'after_setup_theme', 'hasarahouse_fnc_setup' );

/**
 * batch including all files in a path.
 *
 * @param String $path : PATH_DIR/*.php or PATH_DIR with $ifiles not empty
 */
function hasarahouse_pbr_includes( $path, $ifiles=array() ){
 
}

/**
 * Get Theme Option Value.
 * @param String $name : name of prameters 
 */
function hasarahouse_fnc_theme_options($name, $default = false) {
  
    // get the meta from the database
    $options = ( get_option( 'pbr_theme_options' ) ) ? get_option( 'pbr_theme_options' ) : null;
   
    // return the option if it exists
    if ( isset( $options[$name] ) ) {
        return apply_filters( 'pbr_theme_options_$name', $options[ $name ] );
    }
    if( get_option( $name ) ){
        return get_option( $name );
    }
    // return default if nothing else
    return apply_filters( 'pbr_theme_options_$name', $default );
}
/**
 * Adjust content_width value for image attachment template.
 *
 * @since hasarahouse 1.0
 */
function hasarahouse_fnc_content_width() {
	if ( is_attachment() && wp_attachment_is_image() ) {
		$GLOBALS['content_width'] = 810;
	}
}
add_action( 'template_redirect', 'hasarahouse_fnc_content_width' );

/**
 * Require function for including 3rd plugins
 *
 */
require_once(  get_template_directory() . '/inc/plugins/class-tgm-plugin-activation.php' );

function hasarahouse_fnc_get_load_plugins(){

	$plugins[] =(array(
		'name'                     => esc_html__('MetaBox','hasarahouse'), // The plugin name
	    'slug'                     => 'meta-box', // The plugin slug (typically the folder name)
	    'required'                 => true, // If false, the plugin is only 'recommended' instead of required
	));

	$plugins[] =(array(
		'name'                     => esc_html__('Contact Form 7','hasarahouse'), // The plugin name
	    'slug'                     => 'contact-form-7', // The plugin slug (typically the folder name)
	    'required'                 => true, // If false, the plugin is only 'recommended' instead of required
	));

	$plugins[] =(array(
		'name'                     => esc_html__('MailChimp', 'hasarahouse'),// The plugin name
	    'slug'                     => 'mailchimp-for-wp', // The plugin slug (typically the folder name)
	    'required'                 =>  true
	));

	$plugins[] =(array(
		'name'                     => esc_html__('WPBakery Page Builder','hasarahouse'), // The plugin name
	    'slug'                     => 'js_composer', // The plugin slug (typically the folder name)
	    'required'                 => true,
	    'source'				   => get_stylesheet_directory() . '/plugins/js_composer.zip',
	));

	$plugins[] =(array(
		'name'                     => esc_html__('Slider Revolution','hasarahouse'), // The plugin name
        'slug'                     => 'revslider', // The plugin slug (typically the folder name)
        'required'                 => true ,
        'source'				   => get_stylesheet_directory() . '/plugins/revslider.zip',
	));

	$plugins[] =(array(
		'name'                     => esc_html__('PBR Themer For Themes','hasarahouse'), // The plugin name
        'slug'                     => 'pbrthemer', // The plugin slug (typically the folder name)
        'required'                 => true ,
        'source'				   => get_stylesheet_directory() . '/plugins/pbrthemer.zip',
	));

	$plugins[] =(array(
		'name'                     => esc_html__('WpOpal Export Data','hasarahouse'), // The plugin name
        'slug'                     => 'wpopal-export-data', // The plugin slug (typically the folder name)
        'required'                 => true ,
        'source'				   => get_stylesheet_directory() . '/plugins/opalexport.zip',
	));

	$plugins[] =(array(
		'name'                     => esc_html__('Opal Estate','hasarahouse'), // The plugin name
        'slug'                     => "opal-estate", // The plugin slug (typically the folder name)
        'required'                 => true 
	));

	$plugins[] =(array(
		'name'                     => esc_html__('Opal Membership','hasarahouse'), // The plugin name
	    'slug'                     => 'opalmembership', // The plugin slug (typically the folder name)
	    'required'                 => true, // If false, the plugin is only 'recommended' instead of required
	    'source'				   => get_stylesheet_directory() . '/plugins/opalmembership.zip',
	));

	$plugins[] =(array(
		'name'                     => esc_html__('Snazzy Maps - Map Custom Styles','hasarahouse'), // The plugin name
	    'slug'                     => 'snazzy-maps', // The plugin slug (typically the folder name)
	    'required'                 => true, // If false, the plugin is only 'recommended' instead of required
	));

	tgmpa( $plugins );
}

/**
 * Register three mode widget areas.
 *
 * @since hasarahouse 1.0
 */
function hasarahouse_fnc_registart_widgets_sidebars() {
	 
	register_sidebar( 
	array(
		'name'          => esc_html__( 'Sidebar Default', 'hasarahouse' ),
		'id'            => 'sidebar-default',
		'description'   => esc_html__( 'Appears on posts and pages in the sidebar.', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget  clearfix %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span><span>',
		'after_title'   => '</span</span></h3>',
	));

	register_sidebar( 
	array(
		'name'          => esc_html__( 'Newsletter' , 'hasarahouse'),
		'id'            => 'newsletter',
		'description'   => esc_html__( 'Appears on posts and pages in the sidebar.', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget  clearfix %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span><span>',
		'after_title'   => '</span</span></h3>',
	));

	register_sidebar( 
	array(
		'name'          => esc_html__( 'Social' , 'hasarahouse'),
		'id'            => 'social',
		'description'   => esc_html__( 'Appears on content in the sidebar.', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget  clearfix %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span><span>',
		'after_title'   => '</span></span></h3>',
	));

	register_sidebar( 
	array(
		'name'          => esc_html__( 'Left Sidebar' , 'hasarahouse'),
		'id'            => 'sidebar-left',
		'description'   => esc_html__( 'Appears on posts and pages in the sidebar.', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget widget-style  clearfix %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span><span>',
		'after_title'   => '</span></span></h3>',
	));

	register_sidebar(
	array(
		'name'          => esc_html__( 'Right Sidebar' , 'hasarahouse'),
		'id'            => 'sidebar-right',
		'description'   => esc_html__( 'Appears on posts and pages in the sidebar.', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span><span>',
		'after_title'   => '</span></span></h3>',
	));

	register_sidebar( 
	array(
		'name'          => esc_html__( 'Blog Left Sidebar' , 'hasarahouse'),
		'id'            => 'blog-sidebar-left',
		'description'   => esc_html__( 'Appears on posts and pages in the sidebar.', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span><span>',
		'after_title'   => '</span></span></h3>',
	));

	register_sidebar( 
	array(
		'name'          => esc_html__( 'Blog Right Sidebar', 'hasarahouse'),
		'id'            => 'blog-sidebar-right',
		'description'   => esc_html__( 'Appears on posts and pages in the sidebar.', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span><span>',
		'after_title'   => '</span></span></h3>',
	));

	register_sidebar( 
	array(
		'name'          => esc_html__( 'Left Topbar' , 'hasarahouse'),
		'id'            => 'left-top-bar',
		'description'   => esc_html__( 'Appears on posts and pages in the topbar.', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
		'after_widget'  => '</aside>',
	));
	
	if( function_exists("pbr_themer_widgets_init")){
		register_sidebar( 
		array(
			'name'          => esc_html__( 'Header Right sidebar' , 'hasarahouse'),
			'id'            => 'header-sidebar-right',
			'description'   => esc_html__( 'Appears on posts and pages in the header.', 'hasarahouse'),
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget'  => '</aside>',
		));

		register_sidebar( 
		array(
			'name'          => esc_html__( 'Header Left sidebar' , 'hasarahouse'),
			'id'            => 'header-sidebar-left',
			'description'   => esc_html__( 'Appears on posts and pages in the header.', 'hasarahouse'),
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget'  => '</aside>',
		));

		register_sidebar( 
		array(
			'name'          => esc_html__( 'Footer 1' , 'hasarahouse'),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'Appears in the footer section of the site.', 'hasarahouse'),
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		));

		register_sidebar( 
		array(
			'name'          => esc_html__( 'Footer 2' , 'hasarahouse'),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'Appears in the footer section of the site.', 'hasarahouse'),
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		));

		register_sidebar( 
		array(
			'name'          => esc_html__( 'Footer 3' , 'hasarahouse'),
			'id'            => 'footer-3',
			'description'   => esc_html__( 'Appears in the footer section of the site.', 'hasarahouse'),
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		));

		register_sidebar( 
		array(
			'name'          => esc_html__( 'Footer 4' , 'hasarahouse'),
			'id'            => 'footer-4',
			'description'   => esc_html__( 'Appears in the footer section of the site.', 'hasarahouse'),
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		));

		register_sidebar( 
		array(
			'name'          => esc_html__( 'User Sidebar' , 'hasarahouse'),
			'id'            => 'user-sidebar',
			'description'   => esc_html__( 'Appears on posts and pages in the sidebar', 'hasarahouse'),
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		));

		register_sidebar( 
		array(
			'name'          => esc_html__( 'IDX Sidebar' , 'hasarahouse'),
			'id'            => 'idx-sidebar',
			'description'   => esc_html__( 'Appears on posts and pages in the sidebar', 'hasarahouse'),
			'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		));
	}

	register_sidebar( 
	array(
		'name'          => esc_html__( 'Copyright' , 'hasarahouse'),
		'id'            => 'copyright',
		'description'   => esc_html__( 'Appears on posts and pages in the sidebar', 'hasarahouse'),
		'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	));
	
}
add_action( 'widgets_init', 'hasarahouse_fnc_registart_widgets_sidebars' );

/**
 * Register Lato Google font for mode.
 *
 * @since hasarahouse 1.0
 *
 * @return string
 */
function hasarahouse_fnc_font_url() {
	 
	$fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by poppins, playfairdisplay, translate this to 'off'. Do not translate
    * into your own language.
    */

	$poppins         = _x( 'on', 'Poppins font: on or off', 'hasarahouse' );
	
	$RobotoCondensed = _x( 'on', 'Poppins font: on or off', 'hasarahouse' );
	
	$Roboto          = _x( 'on', 'Poppins font: on or off', 'hasarahouse' );
	
	$playfairdisplay = _x( 'on', 'Playfairdisplay font: on or off', 'hasarahouse' );

    if ( 'off' !== $poppins || 'off' !== $playfairdisplay || 'off' !== $RobotoCondensed || 'off' !== $Roboto) {
        $font_families = array();

        if ( 'off' !== $poppins ) {
            $font_families[] = 'Poppins: 300,400,500,600,700';
        }

        if ( 'off' !== $playfairdisplay ) {
            $font_families[] = 'Playfair Display: 400,400italic,700,700italic';
        }

        if ( 'off' !== $RobotoCondensed ) {
            $font_families[] = 'Roboto Condensed: 400,400italic,700,700italic';
        }

        if ( 'off' !== $Roboto ) {
            $font_families[] = 'Roboto: 400,500,700';
        }
 
        $query_args = array(
            'family' => ( implode( '%7C', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 		
 		 
 		$protocol = is_ssl() ? 'https:' : 'http:';
        $fonts_url = add_query_arg( $query_args, $protocol .'//fonts.googleapis.com/css' );
    }
 
    return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles for the front end.
 *
 * @since hasarahouse 1.0
 */
function hasarahouse_fnc_scripts() {
	// Add Lato font, used in the main stylesheet.
	wp_enqueue_style( 'hasarahouse-lato', hasarahouse_fnc_font_url(), array(), null );

	// Add Genericons font, used in the main stylesheet.
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '3.0.3' );
	
	if(isset($_GET['pbr-skin']) && $_GET['pbr-skin']) {
		$currentSkin = $_GET['pbr-skin'];
	}else{
		$currentSkin = str_replace( '.css','', hasarahouse_fnc_theme_options('skin','default') );
	}
	if( is_rtl() ){
		if( !empty($currentSkin) && $currentSkin != 'default' ){ 
			wp_enqueue_style( 'hasarahouse-'.$currentSkin.'-style', get_template_directory_uri() . '/css/skins/rtl-'.$currentSkin.'/style.css' );
		}else {
			// Load our main stylesheet.
			wp_enqueue_style( 'hasarahouse-style', get_template_directory_uri() . '/css/rtl-style.css' );
		}
	}
	else {
		if( !empty($currentSkin) && $currentSkin != 'default' ){ 
			wp_enqueue_style( 'hasarahouse-'.$currentSkin.'-style', get_template_directory_uri() . '/css/skins/'.$currentSkin.'/style.css' );
			wp_enqueue_style( 'opalestate-'.$currentSkin.'-style', get_template_directory_uri() . '/css/skins/'.$currentSkin.'/opalestate.css' );
		}else {
			// Load our main stylesheet.
			wp_enqueue_style( 'hasarahouse-style', get_template_directory_uri() . '/css/style.css' );
			wp_enqueue_style( 'opalestate-style'		   , get_template_directory_uri() . '/css/opalestate.css');
		}	
	}	
	
	
	wp_enqueue_script( 'bootstrap-min', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), '20130402' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_style(  'material-design-iconic-font-style'		 , get_template_directory_uri() . '/css/material-design-iconic-font.min.css');
	wp_enqueue_style(  'Pe-icon-7-stroke-style', get_template_directory_uri() . '/css/Pe-icon-7-stroke.min.css');
	wp_enqueue_style(  'prettyPhoto-style', get_template_directory_uri() . '/css/prettyPhoto.css');
	
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/js/owl-carousel/owl.carousel.js', array( 'jquery' ), '20150315', true );
	wp_enqueue_script( 'prettyphoto',	get_template_directory_uri().'/js/jquery.prettyPhoto.js',array(),false,true);
	wp_enqueue_script( 'stickysidebar',	get_template_directory_uri().'/js/sticky-kit.js', array( 'jquery' ), '20150315', true );
	wp_enqueue_script( 'hasarahouse-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '20150315', true );
	wp_localize_script('hasarahouse-script', 'hasarahouseAjax', array( 'ajaxurl' => esc_url(admin_url( 'admin-ajax.php' ))));

	/**
	 * Check and load to support visual composer
	 */
	if( in_array( 'dsidxpress/dsidxpress.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ){
		wp_enqueue_style( 'idx', get_template_directory_uri() . '/css/idx.css');
	}
}
add_action( 'wp_enqueue_scripts', 'hasarahouse_fnc_scripts' );

/**
 * Enqueue Google fonts style to admin screen for custom header display.
 *
 * @since hasarahouse 1.0
 */
function hasarahouse_fnc_admin_fonts() {
	wp_enqueue_style( 'hasarahouse-lato', hasarahouse_fnc_font_url(), array(), null );
}
add_action( 'admin_print_scripts-appearance_page_custom-header', 'hasarahouse_fnc_admin_fonts' );


/**
 * Implement rick meta box for post and page, custom post types. These 're used with metabox plugins
 */
if( is_admin() ){
	require_once(  get_template_directory() . '/inc/admin/functions.php' );
}
//require_once(  get_template_directory() . '/inc/classes/account.php' );
require_once(  get_template_directory() . '/inc/classes/nav.php' );
require_once(  get_template_directory() . '/inc/classes/offcanvas-menu.php' );

require_once(  get_template_directory() . '/inc/custom-header.php' );
require_once(  get_template_directory() . '/inc/customizer.php' );
require_once(  get_template_directory() . '/inc/function-post.php' );
require_once(  get_template_directory() . '/inc/function-unilty.php' );
require_once(  get_template_directory() . '/inc/functions-import.php' );
require_once(  get_template_directory() . '/inc/template-hook.php' );
require_once(  get_template_directory() . '/inc/template-tags.php' );
require_once(  get_template_directory() . '/inc/template.php' );
 
/**
 * Check and load to support visual composer
 */
if(  in_array( 'js_composer/js_composer.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) && class_exists('WPBakeryVisualComposerAbstract') ){
	require_once(  get_template_directory() . '/inc/vendors/visualcomposer/class-vc-elements.php' );
	require_once(  get_template_directory() . '/inc/vendors/visualcomposer/class-vc-extends.php' );
	require_once(  get_template_directory() . '/inc/vendors/visualcomposer/class-vc-news.php' );
	require_once(  get_template_directory() . '/inc/vendors/visualcomposer/class-vc-theme.php' );
	require_once(  get_template_directory() . '/inc/vendors/visualcomposer/function-vc.php' );

	if ( class_exists('dsIdxGlobals') ) {
		require_once(  get_template_directory() . '/inc/vendors/dsidxpress/function-idx.php' );
	}

}

/**
 * Check and load to support visual composer
 */
if(  in_array( 'opal-estate/opal-estate.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) )  ){
	require_once(  get_template_directory() . '/inc/vendors/opalestate/customizer.php' );
	require_once(  get_template_directory() . '/inc/vendors/opalestate/functions.php' );
}

add_filter( 'upload_mimes', 'hasarahouse_enable_extended_upload', 1, 1 );
function hasarahouse_enable_extended_upload ( $mime_types = array() ) {
	$mime_types['json'] = 'application/json';
	return $mime_types;
}
if ( isset( $_FILES['widget-upload-file'] ) ) {
	define('ALLOW_UNFILTERED_UPLOADS', true);
}

if(class_exists('PBR_User_Account')){
	new PBR_User_Account();
}

if (class_exists('OpalEstate')) {
    add_filter('opalestate_google_map_api_uri', 'hasara_api');
    function hasara_api($link_api)
    {
        $key = opalestate_options('google_map_api_keys', 'AIzaSyA9EEZ-PAHkJdON1Yu_ZkBoyplUgbYpuR4');
        $link_api = '//maps.googleapis.com/maps/api/js?sensor=false&libraries=places&key=' . esc_attr($key) . '';
        return $link_api;
    }
}