<?php 
/**
 * Hook to top bar layout
 */
function hasarahouse_fnc_topbar_layout(){
	$layout = hasarahouse_fnc_get_header_layout();
	get_template_part( 'page-templates/parts/topbar', $layout );
	get_template_part( 'page-templates/parts/topbar', 'mobile' );
}

add_action( 'hasarahouse_template_header_before', 'hasarahouse_fnc_topbar_layout' );

/**
 * Hook to select header layout for archive layout
 */
function hasarahouse_fnc_get_header_layout( $layout='' ){
	global $post; 

	$layout = $post && get_post_meta( $post->ID, 'hasarahouse_header_layout', 1 ) ? get_post_meta( $post->ID, 'hasarahouse_header_layout', 1 ) : hasarahouse_fnc_theme_options( 'headerlayout' );
	if ($layout == 'default') {
		$layout = '';
	}
 	if( $layout ){
 		return trim( $layout );
 	}elseif ( $layout = hasarahouse_fnc_theme_options('header_skin','') ){
 		return trim( $layout );
 	}

	return $layout;
} 

add_filter( 'hasarahouse_fnc_get_header_layout', 'hasarahouse_fnc_get_header_layout' );

/**
 * Hook to select header layout for archive layout
 */
function hasarahouse_fnc_get_footer_profile( $profile='default' ){

	global $post; 

	$profile =  $post? get_post_meta( $post->ID, 'hasarahouse_footer_profile', 1 ):null ;

 	if( $profile ){
 		return trim( $profile );
 	}elseif ( $profile = hasarahouse_fnc_theme_options('footer-style', $profile ) ){  
 		return trim( $profile );
 	}

	return $profile;
} 

add_filter( 'hasarahouse_fnc_get_footer_profile', 'hasarahouse_fnc_get_footer_profile' );


/**
 * Render Custom Css Renderig by Visual composer
 */
if ( !function_exists( 'hasarahouse_fnc_print_style_footer' ) ) {
	function hasarahouse_fnc_print_style_footer(){
		$footer =  hasarahouse_fnc_get_footer_profile( 'default' );
		if($footer!='default'){
			$shortcodes_custom_css = get_post_meta( $footer, '_wpb_shortcodes_custom_css', true );
			if ( ! empty( $shortcodes_custom_css ) ) {
				echo '<style>
					'.$shortcodes_custom_css.'
					</style>';
			}
		}
	}
	add_action('wp_head','hasarahouse_fnc_print_style_footer', 18);
}


/**
 * Hook to show breadscrumbs
 */
function hasarahouse_fnc_render_breadcrumbs(){
	
	global $post;
	$classes = array();
	$classes[] = 'pbr-breadscrumb';
	if( is_object($post) && is_page() ){
		$disable = get_post_meta( $post->ID, 'hasarahouse_disable_breadscrumb', 1 );  
		if(  $disable || is_front_page() ){
			return true; 
		}
		$bgimage = get_post_meta( $post->ID, 'hasarahouse_image_breadscrumb', 1 );  
		$color 	 = get_post_meta( $post->ID, 'hasarahouse_color_breadscrumb', 1 );  
		$bgcolor = get_post_meta( $post->ID, 'hasarahouse_bgcolor_breadscrumb', 1 );  

		$style = array();
		if( $bgcolor  ){
			$style[] = 'background-color:'.$bgcolor;
		}

		if( $bgimage  ){ 
			$bgimage = wp_get_attachment_url($bgimage);
		}

		if( $color  ){ 
			$style[] = 'color:'.$color;
		}
		if ( !empty($style) ) {
			$estyle = !empty($style)? 'style="'.implode(";", $style).'"':"";
		}  

	} elseif ( is_category() || is_archive( ) ) {
		$bgimage = hasarahouse_fnc_theme_options('blog-archive-breadcrumb');
		$classes[] = 'breadcrumb-archive-blog';
	} elseif ( is_singular('post') ) {
		$bgimage = hasarahouse_fnc_theme_options('blog-single-breadcrumb');
		$classes[] = 'breadcrumb-single-blog';
	} elseif ( is_singular('opalestate_property') || is_tax('property_category') || is_post_type_archive( 'opalestate_property' ) ) {
		$bgimage = hasarahouse_fnc_theme_options('image-property-breadcrumb');
		$classes[] = 'breadcrumb-property';
	} elseif ( is_singular('opalestate_agent') || is_post_type_archive( 'opalestate_agent' ) ) {
		$bgimage = hasarahouse_fnc_theme_options('image-agent-breadcrumb');
	} else {
		$classes[] = 'breadcrumb-page';
		$bgimage = hasarahouse_fnc_theme_options('breadcrumb-image');
	}


	if( !empty($bgimage)  ){ 
		$url = is_numeric($bgimage)  ? wp_get_attachment_url($bgimage): $bgimage;
		
	}else{
		$url = hasarahouse_fnc_theme_options('breadcrumb-image');
	}
	$style[] =  ($url) ? 'background-image:url(\''.$url.'\')' : "";
 
	if( isset($url) && strpos($url, get_site_url()) !== false ){  
		$estyle = !empty($style)? 'style="'.implode(";", $style).'"':"";
	}else {
		$estyle = '';
	}
	
	echo '<section id="pbr-breadscrumb" class="'.implode(" ", $classes).'" '.$estyle.'><div class="container">';
			hasarahouse_fnc_breadcrumbs();
	echo '</div></section>';

}

add_action( 'hasarahouse_template_main_before', 'hasarahouse_fnc_render_breadcrumbs' ); 

 
/**
 * Main Container
 */

function hasarahouse_template_main_container_class( $class ){
	global $post; 
	global $hasarahouse_wpopconfig;
	if( !is_object($post) ){
		return;
	}
	$layoutcls = get_post_meta( $post->ID, 'hasarahouse_enable_fullwidth_layout', 1 );
	
	if( $layoutcls ) {
		$hasarahouse_wpopconfig['layout'] = 'fullwidth';
		return 'container-fluid';
	}
	return $class;
}
add_filter( 'hasarahouse_template_main_container_class', 'hasarahouse_template_main_container_class', 1 , 1  );
add_filter( 'hasarahouse_template_main_content_class', 'hasarahouse_template_main_container_class', 1 , 1  );



function hasarahouse_template_footer_before(){
	return get_sidebar( 'newsletter' );
}

add_action( 'hasarahouse_template_footer_before', 'hasarahouse_template_footer_before' );


/**
 * Get Configuration for Page Layout
 *
 */
function hasarahouse_fnc_get_page_sidebar_configs( $configs='' ){

	global $post; 

	if( $post ){
		$left  =  get_post_meta( $post->ID, 'hasarahouse_leftsidebar', 1 );
		$right =  get_post_meta( $post->ID, 'hasarahouse_rightsidebar', 1 );
		return hasarahouse_fnc_get_layout_configs( $left, $right );
	}
	
	return hasarahouse_fnc_get_layout_configs( '', '' );
	
}

add_filter( 'hasarahouse_fnc_get_page_sidebar_configs', 'hasarahouse_fnc_get_page_sidebar_configs', 1, 1 );


function hasarahouse_fnc_get_single_sidebar_configs( $configs='' ){

	global $post; 

	$left  =  get_post_meta( $post->ID, 'hasarahouse_leftsidebar', 1 );
	$right =  get_post_meta( $post->ID, 'hasarahouse_rightsidebar', 1 );

	if ( empty( $left ) ) {
		$left  =  hasarahouse_fnc_theme_options( 'blog-single-left-sidebar' ); 
	}

	if ( empty( $right ) ) {
		$right =  hasarahouse_fnc_theme_options( 'blog-single-right-sidebar' ); 
	}

	return hasarahouse_fnc_get_layout_configs( $left, $right );
}

add_filter( 'hasarahouse_fnc_get_single_sidebar_configs', 'hasarahouse_fnc_get_single_sidebar_configs', 1, 1 );

function hasarahouse_fnc_get_archive_sidebar_configs( $configs='' ){

	global $post; 


	$left  =  hasarahouse_fnc_theme_options( 'blog-archive-left-sidebar' ); 
	$right =  hasarahouse_fnc_theme_options( 'blog-archive-right-sidebar' ); 
 	
	return hasarahouse_fnc_get_layout_configs( $left, $right );
}

add_filter( 'hasarahouse_fnc_get_archive_sidebar_configs', 'hasarahouse_fnc_get_archive_sidebar_configs', 1, 1 );
add_filter( 'hasarahouse_fnc_get_category_sidebar_configs', 'hasarahouse_fnc_get_archive_sidebar_configs', 1, 1 );

/**
 *
 */
function hasarahouse_fnc_get_layout_configs( $left, $right ){
	$configs = array();
	$configs['main'] = array( 'class' => 'col-lg-8 col-md-8 col-sm-8' );

	$configs['sidebars'] = array( 
		'left'  => array( 'sidebar' => $left, 'active' => is_active_sidebar( $left ), 'class' => 'col-lg-4 col-md-4 col-sm-4'  ),
		'right' => array( 'sidebar' => $right, 'active' => is_active_sidebar( $right ), 'class' => 'col-lg-4 col-md-4 col-sm-4' ) 
	); 

	if( $left && $right ){
		$configs['main'] = array( 'class' => 'col-lg-8 col-md-8 col-sm-8' );
	} elseif( empty($left) && empty($right) ){
		$configs['main'] = array( 'class' => 'col-lg-12 col-md-12' );
	}
	return $configs; 
}